@@ -149,7 +149,7 @@ class MainToolbox(ToolbarBox):
 
         self.refresh_filters()
 
-        self.connect('size_allocate', self.__size_allocate_cb)
+        self.connect('size-allocate', self.__size_allocate_cb)
 
     def __size_allocate_cb(self, widget, allocation):
         GLib.idle_add(self._update_buttons, allocation.width)
@@ -458,13 +458,7 @@ class MainToolbox(ToolbarBox):
                              'callback': self._what_palette_cb,
                              'id': bundle_id})
         finally:
-            def _cmp(a, b):
-                if a['label'] < b['label']:
-                    return -1
-                else:
-                    return 1
-
-            for item in sorted(what_list_activities, _cmp):
+            for item in sorted(what_list_activities, key=lambda x: x['label']):
                 self._what_list.append(item)
 
             if self._what_widget_contents is not None:
@@ -1013,6 +1007,8 @@ class FilterToolItem(Gtk.ToolButton):
             invoker.draw_rectangle(cr, self.palette)
 
         return False
+
+
 if hasattr(FilterToolItem, 'set_css_name'):
     FilterToolItem.set_css_name('filtertoolbutton')
 
