@@ -57,7 +57,7 @@ class ObjectPalette(Palette):
         'volume-error': (GObject.SignalFlags.RUN_FIRST, None,
                          ([str, str])),
         'choose-project': (GObject.SignalFlags.RUN_FIRST, None,
-                          ([object])),
+                           ([object])),
     }
 
     def __init__(self, journalactivity, metadata, detail=False):
@@ -627,7 +627,7 @@ class BatchOperator(GObject.GObject):
             # this is only in the case the operation already started
             # and the user want stop it.
             self._stop_batch_execution()
-        elif hasattr(self, '_object_index') == False:
+        elif not hasattr(self, '_object_index'):
             self._object_index = 0
             GLib.idle_add(self._operate_by_uid_internal)
 
